<?php
  header('Content-type: text/plain', true);

  include_once '../includes/aibridge.class.php';
  include_once '../includes/globals.php';
  include_once '../includes/rosetta.class.php';

  $key = array(
    'target' => 't',
    'label'  => 'l',
    'suffix' => 's',
    'device' => 'd',
    'mount'  => 'm');
  $deviceArray = array();
  $deviceArray['key'] = $key;
  $deviceArray['data'] = array();

  // If we are running online, we will include the hardrive location
  if (IS_ONLINE)
  {
    $device = array();
    if (IS_WINDOWS)
      $device[$key['target']] = 'winhardrive';
    else
      $device[$key['target']] = 'hardrive';
    $device[$key['label']]    = 'hardrive';
    $device[$key['suffix']]   = WRITE_DIRECTORY;
    $device[$key['device']]   = '';
    $device[$key['mount']]    = WRITE_DIRECTORY;

    $deviceArray['data'][] = $device;
  }
  // Check for an internal floppy bay
  $xml = new DomDocument(file_get_contents(IDRESULT_PATH));
  $xpath = xpath_new_context($xml->document_element());
  $disketteDevice = @ xpath_eval($xpath, 'category/device[@class="Diskette"]');
  if (count($disketteDevice->nodeset) > 0)
  {
    if (IS_WINDOWS)
    {
      if (file_exists('a:/'))
      {
        $device = array();
        $device[$key['target']] = 'winfloppy';
        $device[$key['label']]  = 'floppy';
        $device[$key['suffix']] = 'a:/';
        $device[$key['device']] = '';
        $device[$key['mount']]  = 'a:/';

        $deviceArray['data'][] = $device;
      }
    }
    else
    {
      if (file_exists('/dev/fd0'))
      {
        $device = array();
        $device[$key['target']] = 'floppy';
        $device[$key['label']]  = 'floppy';
        $device[$key['suffix']] = '';
        $device[$key['device']] = '/dev/fd0';
        $device[$key['mount']]  = '/mnt/floppy';

        $deviceArray['data'][] = $device;
      }
    }
  }
  // Check for connected USB Devices (Linux only)
  if (IS_LINUX)
  {
    $usbFiles = glob('/proc/scsi/usb-storage*/*');
    if (count($usbFiles > 0))
    {
      $usbDevices = array();
      foreach ($usbFiles as $file)
      {
        $fileContent = file_get_contents($file);
        $matches = array();
        $pattern = '/Host[\s]+([^\s:]+):.*Protocol:[\s]+(.*)Transport:.*/';
        $match = preg_match($pattern, clean($fileContent), $matches); // Parse the file for Host and Protocol
        // Continue gathering information only if we were able to extract what we needed
        if ($match > 0)
        {
          //$usbDevices[] = array();
          //$usbDevice = &$usbDevices[count($usbDevices)-1]; // reference last element of $usbDevices array
          $usbDevice = array();
          $usbDevice['host'] = trim($matches[1]);
          $usbDevice['protocol'] = trim($matches[2]);
          // Some distros (RH3) specify an Attached value. If Attached = Yes or Attached is missing, then device is currently connected
          $pattern = '/Attached:[\s]+([^\s]*)/';
          $match = preg_match($pattern, clean($fileContent), $matches);
          if ($match > 0)
          {
            if (strstr($matches[1], 'Yes'))
              $usbDevice['attached'] = true;
            else
              $usbDevice['attached'] = false;
          }
          else
          {
            // If Attached is not defined in the file, we assume that this system only retains files for attached devices
            $usbDevice['attached'] = true;
          }
          // Only continue if device is attached
          if ($usbDevice['attached'] == true) 
          {
            // Now we will read the output of sg_scan and sg_map to locate the correct device
            $stdout = AIBridge::callSgscan();
            $matches = array();
            $pattern = ('/(\/dev\/[^\s]+):[\s]+' . $usbDevice['host'] . '/');
            $match = preg_match($pattern, extractText($stdout), $matches);
            // Only continue if we read sg_scan properly
            if ($match > 0)
            {
              $devsg = $matches[1]; // devsg is the middle man between the scsi host and the device
              $stdout = AIBridge::callSgmap();
              $matches = array();
              $pattern = ('/' . escape($devsg) . '[\s]+([^\s]+)[\s]+/');
              $match = preg_match($pattern, extractText($stdout), $matches);
              // Only continue if we read sg_map properly
              if ($match > 0)
              {
                $usbDevice['device'] = $matches[1];
                // Compare device to its entry in /proc/scsi/scsi to determine if it is a R/W device
                if (file_exists('/proc/scsi/scsi'))
                {
                  $fileContents = file_get_contents('/proc/scsi/scsi');
                  $matches = array();
                  $pattern = ('/Host:[\s]*' . escape($usbDevice['host']) . '[\s]+.*?Vendor:[\s]*([^\s]+).*?Type:[\s]*([^\s]*)/');
                  $match = preg_match($pattern, clean($fileContents), $matches);
                  if ($match > 0)
                  {
                    $usbDevice['vendor'] = trim($matches[1]);
                    $usbDevice['type'] = trim($matches[2]);
                  }
                  else
                  {
                    // If we didn't read /proc/scsi/scsi properly, fill in values with blank strings
                    $usbDevice['vendor'] = '';
                    $usbDevice['type'] = '';
                  }
                }
                // If /proc/scsi/scsi doesn't exist, we will continue anyway with fingers crossed
                // We must get this far before the usbDevice is added to the usbDevices array
                $usbDevices[] = $usbDevice;
              }
            }
          }
        }
      }
      foreach($usbDevices as $usbDevice)
      {
        $usbDeviceArray = array();
        // Check each device and fill in missing information
        if ($usbDevice['protocol'] == 'Transparent SCSI' && $usbDevice['type'] == 'Direct-Access')
        {
          $usbDeviceArray[$key['target']] = 'diskonkey';
          $usbDeviceArray[$key['label']] = 'usb_key';
          $usbDeviceArray[$key['suffix']] = $usbDevice['vendor'];
          $usbDeviceArray[$key['mount']] = '/mnt/diskonkey';
          $usbDeviceArray[$key['device']] = $usbDevice['device'];
        }
        else if (strstr($usbDevice['protocol'], 'Floppy'))
        {
          $usbDeviceArray[$key['target']] = 'usbfloppy';
          $usbDeviceArray[$key['label']] = 'usb_floppy';
          $usbDeviceArray[$key['suffix']] = '';
          $usbDeviceArray[$key['mount']] = '/mnt/usbfloppy';
          $usbDeviceArray[$key['device']] = $usbDevice['device'];
        }
        else
        {
          // This device does not meet requirements for a valud USB R/W device, will ignore
          $usbDeviceArray[$key['target']] = 'unknown';
        }
        // Put all valid devices into $foundDevices
        if ($usbDeviceArray[$key['target']] != 'unknown' && $usbDeviceArray[$key['target']] != '')
        {
          $deviceArray['data'][] = $usbDeviceArray;
        }
      }
    }
  }
//  exit($foundDevices); // outputs string and exits this script
exit(Rosetta::arrayToJSON($deviceArray));

// Utility functions

// Converts newlines to spaces and multiple spaces into a single space
function clean($string)
{
  $string = str_replace("\n", ' ', $string);
  $string = preg_replace('/[\s]+/', ' ', $string);
  //return str_replace("\n", ' ', $string);
  return $string;
}

// Extracts the stdout string from an AI systemCall XML response
function extractText($xml)
{
  $dom = new DomDocument($xml);
  $xpath = xpath_new_context($dom->document_element());
  $stdout = @ xpath_eval($xpath, '//stdout');
  $string =  $stdout->nodeset[0]->get_content();
  return clean($string);
}

// Escapes '/' characters for a regexp
function escape($string)
{
  $string = clean($string);
  return str_replace('/', '\\/', $string);
}

?>
