<?php
  header('Content-type: text/html; charset=utf-8', true);
  header('Cache-control: no-cache', true);
  header('Pragma: no-cache');

  include_once '../includes/globals.php';
  include_once '../includes/aibridge.class.php';
  
  $diagnosisLog = AIBridge::getDiagnosisLog();
  
  $xml = new DomDocument($diagnosisLog);
  $xpath = xpath_new_context($xml->document_element());
  $diagnosisLogRecords = @xpath_eval($xpath, '/diagnosisLogRecord');
  
  outputViewHeader();
  echo '<script type="text/javascript" src="../js/lib.js"></script>';
  echo '<script type="text/javascript" src="js/diagnosisLog.js"></script>';
  echo '</head>';
  echo ('<body onload="init(' . ((DEBUG_MODE === true) ? 'true' : 'false') . ');">');
  echo '<table class="log" id="diagnosisLog">';
  
  if (count($diagnosisLogRecords->nodeset) <= 0)
  {
    echo '<tr class="message">';
    echo ('<td>' . translate('MSG_DIAGNOSIS_LOG') . ' ' . translate('MSG_IS_EMPTY') . '</td>');
    echo '</tr>';
  }
  else
  {
    echo '<thead>';
    echo '<tr>';
    echo '<th class="icon"></th>';
    echo ('<th class="test">' . translate('MSG_DEVICE') . ', ' . translate('MSG_TEST') . '</th>');
    echo ('<th class="number">' . translate('MSG_NUMBER_OF_TIMES_DIAGNOSED') . '</th>');
    echo ('<th class="count">' . translate('MSG_FAILED') . ' ' . translate('MSG_COUNT') . '</th>');
    echo ('<th class="count">' . translate('MSG_PASSED_WITH_WARNINGS') . ' ' . translate('MSG_COUNT') . '</th>');
    echo ('<th class="time">' . translate('MSG_DIAGNOSIS_TIME') . '</th>');
    echo '</tr>';
    echo '</thead>';
    echo '<tbody>';
    foreach ($diagnosisLogRecords->nodeset as $record)
    {
      $test = $record->get_attribute('diagnosisCaption');
      $passedCount = $record->get_attribute('passedCount');
      $warningCount = $record->get_attribute('passedWithWarningsCount');
      $failedCount = $record->get_attribute('failedCount');
      $numberOfTests = ($passedCount + $warningCount + $failedCount);
      $time = $record->get_attribute('testTime');
      if ($failedCount > 0)
        $icon = '../images/status_failed.gif';
      else if ($warningCount > 0)
        $icon = '../images/status_warning.gif';
      else
        $icon = '../images/status_passed.gif';
      //$icon = ($failedCount > 0) ? '../images/status_failed.gif' : '../images/status_passed.gif';
      echo '<tr>';
      echo ('<td class="icon"><img src="' . $icon . '" /></td>');
      echo ('<td class="test">' . $test . '</td>');
      echo ('<td class="number">' . $numberOfTests . '</td>');
      echo ('<td class="count">' . $failedCount . '</td>');
      echo ('<td class="count">' . $warningCount . '</td>');
      echo ('<td class="time">' . $time . '</td>');
      echo '</tr>';

      $xpath = xpath_new_context($record);
      $diagnosisResultParent = @xpath_eval($xpath, '/diagnosisResult');
      if (count($diagnosisResultParent->nodeset > 0))
      {
        $diagnosisResultParent = $diagnosisResultParent->nodeset[0];
        $xpath = xpath_new_context($diagnosisResultParent);
        $results = @ xpath_eval($xpath, '/diagnosisResult');
        if (count($results->nodeset > 0))
        {
          foreach ($results->nodeset as $device)
          {
            $deviceCaption = $device->get_attribute('caption');
            $xpath = xpath_new_context($device);
            $errors = @ xpath_eval($xpath, '/error');
            $warnings = @ xpath_eval($xpath, '/warning');
            if (count($errors->nodeset) > 0 ||
                count($warnings->nodeset) > 0)
            {
              echo '<tr>';
              echo '<td></td>';
              echo '<td colspan="5">';
              echo (translate('MSG_ERRORS_AND_WARNINGS_FOR') . ' ' . $deviceCaption);
              echo '<table class="errorsAndWarnings">';
              foreach ($errors->nodeset as $error)
              {
                $caption = $error->get_attribute('caption');
                $time = $error->get_attribute('time');
                $code = $error->get_attribute('code');
                echo '<tr class="error">';
                echo '<th>Error:</th>';
                echo ('<td class="time">' . $time . '</td>');
                echo ('<td>' . $code . ':</td>');
                echo ('<td>' . $caption . '</td>');
                echo '</tr>';
              }
              foreach ($warnings->nodeset as $warning)
              {
                $caption = $warning->get_attribute('caption');
                echo '<tr class="warning">';
                echo '<th>Warning:</th>';
                echo ('<td colspan="3">' . $caption . '</td>');
                echo '</tr>';
              }
              echo '</table>';
              echo '</td>';
            }
            //echo "<tr><td colspan=\"6\">$deviceCaption</td></tr>";
            //echo "<tr><td colspan=\"6\">Error Count: " . count($errors->nodeset) . "</td></tr>";
            //echo "<tr><td colspan=\"6\">Warning Count: " . count($warnings->nodeset) . "</td></tr>";
          }
        }
      }
    }
    echo '</tbody>';
  }
  
  echo '</table>';
  outputViewFooter();
  //*/
?>
